@@ -1,3 +1,27 @@
+/*******************************************************************************
+ quicktime.h
+
+ libquicktime - A library for reading and writing quicktime/avi/mp4 files.
+ http://libquicktime.sourceforge.net
+
+ Copyright (C) 2002 Heroine Virtual Ltd.
+ Copyright (C) 2002-2007 Members of the libquicktime project.
+
+ This library is free software; you can redistribute it and/or modify it under
+ the terms of the GNU Lesser General Public License as published by the Free
+ Software Foundation; either version 2.1 of the License, or (at your option)
+ any later version.
+
+ This library is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+ details.
+
+ You should have received a copy of the GNU Lesser General Public License along
+ with this library; if not, write to the Free Software Foundation, Inc., 51
+ Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+*******************************************************************************/
+
 #ifndef QUICKTIME_H
 #define QUICKTIME_H
 
@@ -5,9 +29,8 @@
 extern "C" {
 #endif
 
-#include <stdio.h>
-#include <stdlib.h>
 #include <inttypes.h>
+#include <stddef.h>
 
 /* Some public enums needed by most subsequent headers */
 
@@ -19,6 +42,11 @@ extern "C" {
 /** \defgroup general General
     \brief General structures and functions
  */
+
+/** \defgroup log Logging
+    \brief Message handling
+ */
+
   
 /** \defgroup audio Audio
     \brief Audio related definitions and functions
@@ -84,6 +112,32 @@ extern "C" {
 
 */
 
+/** \ingroup log
+ *  \brief Log level
+ */
+
+typedef enum
+  {
+    LQT_LOG_ERROR   = (1<<0),
+    LQT_LOG_WARNING = (1<<1),
+    LQT_LOG_INFO    = (1<<2),
+    LQT_LOG_DEBUG   = (1<<3),
+  } lqt_log_level_t;
+
+/** \ingroup log
+ *  \brief Log callback
+ *  \param level The log level
+ *  \param domain Log domain (e.g. name of the module)
+ *  \param message The message to pass
+ *  \param data Application supplied data
+ */
+
+typedef void (*lqt_log_callback_t)(lqt_log_level_t level,
+                                   const char * domain,
+                                   const char * message,
+                                   void * data);
+
+  
 /** \ingroup General
  *  \brief File types
  *
@@ -99,6 +153,7 @@ typedef enum
     LQT_FILE_AVI_ODML = (1<<3), /*!< Opendml AVI (> 2G) */
     LQT_FILE_MP4      = (1<<4), /*!< .mp4 (ftyp = "mp42") */
     LQT_FILE_M4A      = (1<<5), /*!< .m4a  */
+    LQT_FILE_3GP      = (1<<6), /*!< .3gp  */
   } lqt_file_type_t;
 
   
@@ -234,13 +289,6 @@ typedef enum
     LQT_SAMPLE_FLOAT      /*!< Float (machine native) */
   } lqt_sample_format_t;
   
-
-
-  
-// #include "qtprivate.h"
-
-
-  
 /** \ingroup general
     \brief Quicktime handle
 
