@@ -1,18 +1,37 @@
-#include <config.h>
-#include "funcprotos.h"
-#include <quicktime/quicktime.h>
-#define LQT_LIBQUICKTIME
-#include <quicktime/lqt_codecapi.h>
+/*******************************************************************************
+ pcm.c
 
-#include <string.h>
-#include <stdlib.h>
-#include <math.h>
+ libquicktime - A library for reading and writing quicktime/avi/mp4 files.
+ http://libquicktime.sourceforge.net
 
+ Copyright (C) 2002 Heroine Virtual Ltd.
+ Copyright (C) 2002-2007 Members of the libquicktime project.
 
-#include "pcm.h"
+ This library is free software; you can redistribute it and/or modify it under
+ the terms of the GNU Lesser General Public License as published by the Free
+ Software Foundation; either version 2.1 of the License, or (at your option)
+ any later version.
 
+ This library is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+ details.
+
+ You should have received a copy of the GNU Lesser General Public License along
+ with this library; if not, write to the Free Software Foundation, Inc., 51
+ Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+*******************************************************************************/ 
+
+#include "lqt_private.h"
 #include "ulaw_tables.h"
 #include "alaw_tables.h"
+#define LQT_LIBQUICKTIME
+#include <quicktime/lqt_codecapi.h>
+#include <stdlib.h>
+#include <string.h>
+#include <math.h>
+
+#define LOG_DOMAIN "pcm"
 
 #ifndef HAVE_LRINT
 #define lrint(x) ((long int)(x))
@@ -726,7 +745,6 @@ static int read_audio_chunk(quicktime_t * file, int track,
   quicktime_pcm_codec_t *codec = ((quicktime_codec_t*)track_map->codec)->priv;
 
   bytes = lqt_read_audio_chunk(file, track, chunk, buffer, buffer_alloc, &samples);
-  //  fprintf(stderr, "Chunk: %d, samples: %d %d\n", chunk, samples, bytes);
   bytes_from_samples = samples * codec->block_align;
   if(bytes > bytes_from_samples)
     return bytes_from_samples;
@@ -757,7 +775,7 @@ static int decode_pcm(quicktime_t *file, void * _output, long samples, int track
                                                 &(codec->chunk_buffer_alloc));
     if(codec->chunk_buffer_size <= 0)
       {
-      fprintf(stderr, "decode_pcm: EOF at the beginning of track\n");
+      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "EOF at the beginning of track");
       return 0;
       }
     codec->chunk_buffer_ptr = codec->chunk_buffer;
@@ -800,7 +818,7 @@ static int decode_pcm(quicktime_t *file, void * _output, long samples, int track
     samples_to_skip = file->atracks[track].current_position - chunk_sample;
     if(samples_to_skip < 0)
       {
-      fprintf(stderr, "pcm: Cannot skip backwards\n");
+      lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "Cannot skip backwards");
       samples_to_skip = 0;
       }
     codec->chunk_buffer_ptr = codec->chunk_buffer + samples_to_skip * codec->block_align;
@@ -852,7 +870,6 @@ static int encode_pcm(quicktime_t *file, void * input, long samples, int track)
   quicktime_pcm_codec_t *codec = ((quicktime_codec_t*)track_map->codec)->priv;
   quicktime_trak_t *trak = track_map->track;
 
-  //  fprintf(stderr, "encode_pcm: %d\n", samples);
   
   /* Initialize */
 
@@ -913,8 +930,8 @@ static int encode_pcm(quicktime_t *file, void * input, long samples, int track)
 
 static int set_parameter_pcm(quicktime_t *file, 
                              int track, 
-                             char *key, 
-                             void *value)
+                             const char *key, 
+                             const void *value)
   {
   quicktime_audio_map_t *atrack = &(file->atracks[track]);
   quicktime_pcm_codec_t *codec = ((quicktime_codec_t*)atrack->codec)->priv;
@@ -1070,6 +1087,7 @@ void quicktime_init_codec_in24(quicktime_audio_map_t *atrack)
   /* Init public items */
   codec_base->delete_acodec = delete_pcm;
   codec_base->decode_audio = decode_pcm;
+  codec_base->encode_audio = encode_pcm;
   codec_base->set_parameter = set_parameter_pcm;
   /* Init private items */
   codec = calloc(1, sizeof(*codec));
@@ -1183,7 +1201,7 @@ void quicktime_init_codec_fl32(quicktime_audio_map_t *atrack)
   /* Init public items */
   codec_base->delete_acodec = delete_pcm;
   codec_base->decode_audio = decode_pcm;
-  codec_base->decode_audio = encode_pcm;
+  codec_base->encode_audio = encode_pcm;
 
   /* Init private items */
   codec = calloc(1, sizeof(*codec));
@@ -1232,7 +1250,7 @@ void quicktime_init_codec_fl64(quicktime_audio_map_t *atrack)
   /* Init public items */
   codec_base->delete_acodec = delete_pcm;
   codec_base->decode_audio = decode_pcm;
-  codec_base->decode_audio = encode_pcm;
+  codec_base->encode_audio = encode_pcm;
 
   /* Init private items */
   codec = calloc(1, sizeof(*codec));
@@ -1269,7 +1287,7 @@ void quicktime_init_codec_rawaudio(quicktime_audio_map_t *atrack)
     {
     case 8:
       codec->block_align = atrack->channels;
-      atrack->sample_format = LQT_SAMPLE_INT8;
+      atrack->sample_format = LQT_SAMPLE_UINT8;
       codec->encode = encode_8;
       codec->decode = decode_8;
       break;
@@ -1439,8 +1457,6 @@ static void init_decode_lpcm(quicktime_t * file, int track)
 
   codec->block_align = (table->sample_size/8) * atrack->channels;
 
-  //  fprintf(stderr, "init_decode_lpcm: %p %s\n",
-  //          codec->decode, lqt_sample_format_to_string(atrack->sample_format));
   }
 
 static void init_encode_lpcm(quicktime_t * file, int track)
