@@ -1,7 +1,30 @@
+/*******************************************************************************
+ dv.c
+
+ libquicktime - A library for reading and writing quicktime/avi/mp4 files.
+ http://libquicktime.sourceforge.net
+
+ Copyright (C) 2002 Heroine Virtual Ltd.
+ Copyright (C) 2002-2007 Members of the libquicktime project.
+
+ This library is free software; you can redistribute it and/or modify it under
+ the terms of the GNU Lesser General Public License as published by the Free
+ Software Foundation; either version 2.1 of the License, or (at your option)
+ any later version.
+
+ This library is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+ details.
+
+ You should have received a copy of the GNU Lesser General Public License along
+ with this library; if not, write to the Free Software Foundation, Inc., 51
+ Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+*******************************************************************************/ 
+
+#include "lqt_private.h"
 #include <quicktime/colormodels.h>
-#include <funcprotos.h>
 #include <libdv/dv.h>
-#include <quicktime/quicktime.h>
 #include <pthread.h>
 #include <string.h>
 
@@ -59,13 +82,11 @@ static int check_sequentiality( unsigned char **row_pointers,
 								int height )
 {
 	int i = 0;
-//printf( "dv.c check_sequentiality: %p, %d, %d\n", row_pointers, bytes_per_row, height );
  
 	for(; i < height-1; i++)
 	{
 		if( row_pointers[i+1] - row_pointers[i] != bytes_per_row )
 		{
-//printf( "dv.c check_sequentiality: %p - %p != %p\n", row_pointers[i+1], row_pointers[i], bytes_per_row );
 			return 0;
 		}
 	}
@@ -96,7 +117,6 @@ static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
           return 0;
           }
         
-        //  fprintf(stderr, "Encoding %s\n", (isPAL ? "PAL" : "NTSC"));
         
 	if( codec->dv_encoder != NULL && codec->parameters_changed )
 	{
@@ -109,7 +129,6 @@ static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
 	{
 		pthread_mutex_lock( &libdv_init_mutex );
 
-		//printf( "dv.c encode: Alloc'ing encoder\n" );
 	
 		codec->dv_encoder = dv_encoder_new( codec->rem_ntsc_setup,
 											codec->clamp_luma,
@@ -160,17 +179,14 @@ static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
 		codec->dv_encoder->isPAL = isPAL;
 
 
-//printf("dv.c encode: 1 %d %d %d\n", width_i, height_i, encode_dv_colormodel);
 		dv_encode_full_frame( codec->dv_encoder,
 							  input_rows, encode_dv_colormodel, codec->data );
-//printf("dv.c encode: 2 %d %d\n", width_i, height_i);
 
                 
                 quicktime_write_chunk_header(file, trak, &chunk_atom);
                 result = !quicktime_write_data(file, codec->data, data_length);
                 quicktime_write_chunk_footer(file, trak, vtrack->current_chunk, &chunk_atom, 1);
                 file->vtracks[track].current_chunk++;
-//printf("encode 3\n");
 	}
 
 	return result;
@@ -184,8 +200,8 @@ static int encode(quicktime_t *file, unsigned char **row_pointers, int track)
 
 static int set_parameter(quicktime_t *file, 
 		int track, 
-		char *key, 
-		void *value)
+		const char *key, 
+		const void *value)
 {
 	quicktime_dv_codec_t *codec = ((quicktime_codec_t*)file->vtracks[track].codec)->priv;
 	
