@@ -1,11 +1,34 @@
+/*******************************************************************************
+ clap.c
+
+ libquicktime - A library for reading and writing quicktime/avi/mp4 files.
+ http://libquicktime.sourceforge.net
+
+ Copyright (C) 2002 Heroine Virtual Ltd.
+ Copyright (C) 2002-2007 Members of the libquicktime project.
+
+ This library is free software; you can redistribute it and/or modify it under
+ the terms of the GNU Lesser General Public License as published by the Free
+ Software Foundation; either version 2.1 of the License, or (at your option)
+ any later version.
+
+ This library is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+ details.
+
+ You should have received a copy of the GNU Lesser General Public License along
+ with this library; if not, write to the Free Software Foundation, Inc., 51
+ Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+*******************************************************************************/ 
+
 /*
- * $Id: clap.c,v 1.3 2006/04/13 19:25:48 gmerlin Exp $
- *
- * init, read, write handler for the "clap" (Clean Aperture) atom
+
+ Init, read, write handler for the "clap" (Clean Aperture) atom.
+
 */
 
-#include <funcprotos.h>
-#include <quicktime/quicktime.h>
+#include "lqt_private.h"
 #include <string.h>
 
 void quicktime_clap_init(quicktime_clap_t *clap)
@@ -18,15 +41,15 @@ void quicktime_clap_delete(quicktime_clap_t *clap) { }
 void quicktime_clap_dump(quicktime_clap_t *clap)
 {
 
-	printf("     clean aperture (clap)\n");
-	printf("       cleanApertureWidthN %d\n", clap->cleanApertureWidthN);
-	printf("       cleanApertureWidthD %d\n", clap->cleanApertureWidthD);
-	printf("       cleanApertureHeightN %d\n", clap->cleanApertureHeightN);
-	printf("       cleanApertureHeightD %d\n", clap->cleanApertureHeightD);
-	printf("       horizOffN %d\n", clap->horizOffN);
-	printf("       horizOffD %d\n", clap->horizOffD);
-	printf("       vertOffN %d\n", clap->vertOffN);
-	printf("       vertOffD %d\n", clap->vertOffD);
+	lqt_dump("     clean aperture (clap)\n");
+	lqt_dump("       cleanApertureWidthN %d\n", clap->cleanApertureWidthN);
+	lqt_dump("       cleanApertureWidthD %d\n", clap->cleanApertureWidthD);
+	lqt_dump("       cleanApertureHeightN %d\n", clap->cleanApertureHeightN);
+	lqt_dump("       cleanApertureHeightD %d\n", clap->cleanApertureHeightD);
+	lqt_dump("       horizOffN %d\n", clap->horizOffN);
+	lqt_dump("       horizOffD %d\n", clap->horizOffD);
+	lqt_dump("       vertOffN %d\n", clap->vertOffN);
+	lqt_dump("       vertOffD %d\n", clap->vertOffD);
 }
 
 void quicktime_read_clap(quicktime_t *file, quicktime_clap_t *clap)
