@@ -1,14 +1,48 @@
-#include <funcprotos.h>
-#include <quicktime/quicktime.h>
+/*******************************************************************************
+ dref.c
+
+ libquicktime - A library for reading and writing quicktime/avi/mp4 files.
+ http://libquicktime.sourceforge.net
+
+ Copyright (C) 2002 Heroine Virtual Ltd.
+ Copyright (C) 2002-2007 Members of the libquicktime project.
+
+ This library is free software; you can redistribute it and/or modify it under
+ the terms of the GNU Lesser General Public License as published by the Free
+ Software Foundation; either version 2.1 of the License, or (at your option)
+ any later version.
+
+ This library is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+ details.
+
+ You should have received a copy of the GNU Lesser General Public License along
+ with this library; if not, write to the Free Software Foundation, Inc., 51
+ Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+*******************************************************************************/ 
+
+#include "lqt_private.h"
+#include <stdlib.h>
 #include <string.h>
 
-void quicktime_dref_table_init(quicktime_dref_table_t *table)
+void quicktime_dref_table_init(quicktime_dref_table_t *table, lqt_file_type_t type)
 {
 	table->size = 0;
-	table->type[0] = 'a';
-	table->type[1] = 'l';
-	table->type[2] = 'i';
-	table->type[3] = 's';
+        if(IS_MP4(type))
+          {
+          table->type[0] = 'u';
+          table->type[1] = 'r';
+          table->type[2] = 'l';
+          table->type[3] = ' ';
+          }
+        else
+          {
+          table->type[0] = 'a';
+          table->type[1] = 'l';
+          table->type[2] = 'i';
+          table->type[3] = 's';
+          }
 	table->version = 0;
 	table->flags = 0x0001;
 	table->data_reference = malloc(256);
@@ -48,11 +82,11 @@ void quicktime_write_dref_table(quicktime_t *file, quicktime_dref_table_t *table
 
 void quicktime_dref_table_dump(quicktime_dref_table_t *table)
 {
-	printf("      data reference table (dref)\n");
-	printf("       type %c%c%c%c\n", table->type[0], table->type[1], table->type[2], table->type[3]);
-	printf("       version %d\n", table->version);
-	printf("       flags %ld\n", table->flags);
-	printf("       data %s\n", table->data_reference);
+	lqt_dump("      data reference table (dref)\n");
+	lqt_dump("       type %c%c%c%c\n", table->type[0], table->type[1], table->type[2], table->type[3]);
+	lqt_dump("       version %d\n", table->version);
+	lqt_dump("       flags %ld\n", table->flags);
+	lqt_dump("       data %s\n", table->data_reference);
 }
 
 
@@ -64,13 +98,13 @@ void quicktime_dref_init(quicktime_dref_t *dref)
 	dref->table = 0;
 }
 
-void quicktime_dref_init_all(quicktime_dref_t *dref)
+void quicktime_dref_init_all(quicktime_dref_t *dref, lqt_file_type_t type)
 {
 	if(!dref->total_entries)
 	{
 		dref->total_entries = 1;
 		dref->table = (quicktime_dref_table_t *)malloc(sizeof(quicktime_dref_table_t) * dref->total_entries);
-		quicktime_dref_table_init(&(dref->table[0]));
+		quicktime_dref_table_init(&(dref->table[0]), type);
 	}
 }
 
@@ -90,9 +124,9 @@ void quicktime_dref_dump(quicktime_dref_t *dref)
 {
 	int i;
 	
-	printf("     data reference (dref)\n");
-	printf("      version %d\n", dref->version);
-	printf("      flags %ld\n", dref->flags);
+	lqt_dump("     data reference (dref)\n");
+	lqt_dump("      version %d\n", dref->version);
+	lqt_dump("      flags %ld\n", dref->flags);
 	for(i = 0; i < dref->total_entries; i++)
 	{
 		quicktime_dref_table_dump(&(dref->table[i]));
@@ -109,7 +143,7 @@ void quicktime_read_dref(quicktime_t *file, quicktime_dref_t *dref)
 	dref->table = (quicktime_dref_table_t*)malloc(sizeof(quicktime_dref_table_t) * dref->total_entries);
 	for(i = 0; i < dref->total_entries; i++)
 	{
-		quicktime_dref_table_init(&(dref->table[i]));
+		quicktime_dref_table_init(&(dref->table[i]), file->file_type);
 		quicktime_read_dref_table(file, &(dref->table[i]));
 	}
 }
