@@ -1,4 +1,28 @@
-#include <inttypes.h>
+/*******************************************************************************
+ lqt_divx.c
+
+ libquicktime - A library for reading and writing quicktime/avi/mp4 files.
+ http://libquicktime.sourceforge.net
+
+ Copyright (C) 2002 Heroine Virtual Ltd.
+ Copyright (C) 2002-2007 Members of the libquicktime project.
+
+ This library is free software; you can redistribute it and/or modify it under
+ the terms of the GNU Lesser General Public License as published by the Free
+ Software Foundation; either version 2.1 of the License, or (at your option)
+ any later version.
+
+ This library is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+ details.
+
+ You should have received a copy of the GNU Lesser General Public License along
+ with this library; if not, write to the Free Software Foundation, Inc., 51
+ Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+*******************************************************************************/ 
+
+#include "lqt_private.h"
 
 // Determine of the compressed frame is a keyframe for direct copy
 int quicktime_divx_is_key(unsigned char *data, long size)
@@ -68,7 +92,6 @@ static void flushbits(unsigned char **data,
 	int *bit_pos, 
 	uint64_t *bit_store)
 {
-//printf("flushbits %llx\n", (*bit_store));
 	while((*bit_pos) > 0)
 	{
 		*(*data)++ = (*bit_store) >> 56;
@@ -89,7 +112,7 @@ int quicktime_divx_write_vol(unsigned char *data_start,
 	int vol_width, 
 	int vol_height, 
 	int time_increment_resolution, 
-	float frame_rate)
+	double frame_rate)
 {
 	int written = 0;
 	int bits, fixed_vop_time_increment;
@@ -306,12 +329,6 @@ int quicktime_divx_write_vol(unsigned char *data_start,
 
 
 
-/*
- * for(i = 0; i < data - data_start; i++)
- * 	for(j = 0x80; j >= 1; j /= 2)
- * 		printf("%d", (data_start[i] & j) ? 1 : 0);
- * printf("\n");
- */
 
 
 
