@@ -1,19 +1,37 @@
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+/*******************************************************************************
+ lqt_quicktime.c
 
+ libquicktime - A library for reading and writing quicktime/avi/mp4 files.
+ http://libquicktime.sourceforge.net
+
+ Copyright (C) 2002 Heroine Virtual Ltd.
+ Copyright (C) 2002-2007 Members of the libquicktime project.
+
+ This library is free software; you can redistribute it and/or modify it under
+ the terms of the GNU Lesser General Public License as published by the Free
+ Software Foundation; either version 2.1 of the License, or (at your option)
+ any later version.
+
+ This library is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+ details.
+
+ You should have received a copy of the GNU Lesser General Public License along
+ with this library; if not, write to the Free Software Foundation, Inc., 51
+ Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+*******************************************************************************/ 
+
+#include "lqt_private.h"
+#include "lqt_fseek.h"
 #include <quicktime/colormodels.h>
-#include <quicktime/quicktime.h>
-#include <quicktime/lqt.h>
-#define LQT_LIBQUICKTIME
-#include <quicktime/lqt_codecapi.h>
-#include <lqt_codecinfo_private.h>
-
-#include <funcprotos.h>
-#include <lqt_fseek.h>
-#include <sys/stat.h>
+#include <stdlib.h>
+#include <stdio.h>
 #include <string.h>
+#include <strings.h>
+#include <errno.h>
 
+#define LOG_DOMAIN "core"
 
 static int64_t get_file_length(quicktime_t *file)
 {
@@ -58,14 +76,12 @@ int quicktime_make_streamable(char *in_path, char *out_path)
 /* get the locations of moov and mdat atoms */
 	do
 	{
-/*printf("%x\n", quicktime_position(&file)); */
 		result = quicktime_atom_read_header(&file, &leaf_atom);
 
 		if(!result)
 		{
 			if(quicktime_atom_is(&leaf_atom, "moov"))
 			{
-                        //                                fprintf(stderr, "old moov start: %lld\n", leaf_atom.start);
 				moov_exists = atoms;
 				moov_length = leaf_atom.size;
 			}
@@ -91,16 +107,18 @@ int quicktime_make_streamable(char *in_path, char *out_path)
 	fclose(file.stream);
 
 	if(!moov_exists)
-	{
-		printf("quicktime_make_streamable: no moov atom\n");
-		return 1;
-	}
+          {
+          lqt_log(NULL, LQT_LOG_ERROR, LOG_DOMAIN,
+                  "quicktime_make_streamable: no moov atom");
+          return 1;
+          }
 
 	if(!mdat_exists)
-	{
-		printf("quicktime_make_streamable: no mdat atom\n");
-		return 1;
-	}
+          {
+          lqt_log(NULL, LQT_LOG_ERROR, LOG_DOMAIN,
+                  "quicktime_make_streamable: no mdat atom");
+          return 1;
+          }
 
 /* copy the old file to the new file */
 	if(moov_exists && mdat_exists)
@@ -126,7 +144,9 @@ int quicktime_make_streamable(char *in_path, char *out_path)
 			
 			if(!(new_file.stream = fopen(out_path, "wb")))
 			{
-				perror("quicktime_make_streamable");
+                        lqt_log(NULL, LQT_LOG_ERROR, LOG_DOMAIN,
+                                "quicktime_make_streamable: cannot open output file: %s",
+                                strerror(errno));
 				result =  1;
 			}
 			else
@@ -145,8 +165,8 @@ int quicktime_make_streamable(char *in_path, char *out_path)
                         if(moov_length !=
                            quicktime_position(&new_file) - moov_start)
                           {
-                          fprintf(stderr,
-                                  "Warning: moov size changed from %lld to %lld (Pos: %lld, start: %lld)\n",
+                          lqt_log(NULL, LQT_LOG_ERROR, LOG_DOMAIN,
+                                  "quicktime_make_streamable: moov size changed from %lld to %lld (Pos: %lld, start: %lld)",
                                   moov_length, quicktime_position(&new_file) - moov_start,
                                   quicktime_position(&new_file), moov_start);
                           quicktime_set_position(&new_file, moov_start + moov_length);
@@ -219,13 +239,15 @@ new_file.presave_size, new_file.stream);
 
 
 
-void lqt_set_audio_parameter(quicktime_t *file,int stream, char *key,void *value)
+void lqt_set_audio_parameter(quicktime_t *file,int stream, const char *key,
+                             const void *value)
   {
   quicktime_codec_t *codec = (quicktime_codec_t*)file->atracks[stream].codec;
   if(codec->set_parameter) codec->set_parameter(file, stream, key, value);
   }
 
-void lqt_set_video_parameter(quicktime_t *file,int stream, char *key,void *value)
+void lqt_set_video_parameter(quicktime_t *file,int stream, const char *key,
+                             const void *value)
   {
   quicktime_codec_t *codec = (quicktime_codec_t*)file->vtracks[stream].codec;
   if(codec->set_parameter) codec->set_parameter(file, stream, key, value);
@@ -395,7 +417,7 @@ int lqt_add_audio_track(quicktime_t *file,
 
   file->atracks = realloc(file->atracks, (file->total_atracks+1)*sizeof(quicktime_audio_map_t));
   memset(&(file->atracks[file->total_atracks]), 0, sizeof(quicktime_audio_map_t));
-
+  
   trak = quicktime_add_track(file);
   quicktime_trak_init_audio(file, trak, channels,
                             sample_rate, bits, compressor);
@@ -488,7 +510,6 @@ int lqt_add_video_track(quicktime_t *file,
         /* Get encoding colormodel */
         ((quicktime_codec_t*)(file->vtracks[file->total_vtracks-1].codec))->encode_video(file, (uint8_t**)0, file->total_vtracks-1);
         file->vtracks[file->total_vtracks-1].io_cmodel = file->vtracks[file->total_vtracks-1].stream_cmodel;
-        //        fprintf(stderr, "*** Got encoding colormodel %s\n", lqt_colormodel_to_string(file->vtracks[file->total_vtracks-1].stream_cmodel));
         return 0;
   }
 
@@ -502,7 +523,8 @@ void quicktime_set_framerate(quicktime_t *file, double framerate)
 
 	if(!file->wr)
 	{
-		fprintf(stderr, "quicktime_set_framerate shouldn't be called in read mode.\n");
+		lqt_log(file, LQT_LOG_WARNING, LOG_DOMAIN,
+                        "quicktime_set_framerate shouldn't be called in read mode.");
 		return;
 	}
 
@@ -518,26 +540,25 @@ void quicktime_set_framerate(quicktime_t *file, double framerate)
 
 /* Used for writing only */
 quicktime_trak_t* quicktime_add_track(quicktime_t *file)
-{
-        quicktime_moov_t *moov = &(file->moov);
-        quicktime_trak_t *trak;
-        int i;
+  {
+  quicktime_moov_t *moov = &(file->moov);
+  quicktime_trak_t *trak;
+  
+  //  for(i = moov->total_tracks; i > 0; i--)
+  //    moov->trak[i] = moov->trak[i - 1];
+  
+  trak =
+    moov->trak[moov->total_tracks] =
+    calloc(1, sizeof(quicktime_trak_t));
 
-        for(i = moov->total_tracks; i > 0; i--)
-                moov->trak[i] = moov->trak[i - 1];
-                                                                                                                  
-        trak =
-                moov->trak[0] =
-                calloc(1, sizeof(quicktime_trak_t));
-        quicktime_trak_init(trak);
-        
-        moov->total_tracks++;
-        for(i = 0; i < moov->total_tracks; i++)
-                moov->trak[i]->tkhd.track_id = i + 1;
-        
-        moov->mvhd.next_track_id++;
-        return trak;
-}
+  quicktime_trak_init(trak, file->file_type);
+
+  moov->trak[moov->total_tracks]->tkhd.track_id = moov->mvhd.next_track_id;
+  
+  moov->total_tracks++;
+  moov->mvhd.next_track_id++;
+  return trak;
+  }
 
 /* ============================= Initialization functions */
 
@@ -566,6 +587,12 @@ int quicktime_delete(quicktime_t *file)
 			quicktime_delete_video_map(&(file->vtracks[i]));
 		free(file->vtracks);
 	}
+	if(file->total_ttracks)
+	{
+                for(i = 0; i < file->total_ttracks; i++)
+			lqt_delete_text_map(file, &(file->ttracks[i]));
+		free(file->ttracks);
+	}
 	file->total_atracks = 0;
 	file->total_vtracks = 0;
 
@@ -588,6 +615,7 @@ int quicktime_delete(quicktime_t *file)
 
 	quicktime_moov_delete(&(file->moov));
 	quicktime_mdat_delete(&(file->mdat));
+	quicktime_ftyp_delete(&(file->ftyp));
 	return 0;
 }
 
@@ -620,7 +648,6 @@ int quicktime_get_timescale(double frame_rate)
 	else
 	if((600 / frame_rate) - (int)(600 / frame_rate) != 0) 
 			timescale = (int)(frame_rate * 100 + 0.5);
-//printf("quicktime_get_timescale %f %d\n", 600 / frame_rate, (int)(600 / frame_rate));
 	return timescale;
 }
 
@@ -673,7 +700,8 @@ int quicktime_set_audio_position(quicktime_t *file, int64_t sample, int track)
     file->atracks[track].eof = 0;
     }
   else
-    fprintf(stderr, "quicktime_set_audio_position: track >= file->total_atracks\n");
+    lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN,
+            "quicktime_set_audio_position: track >= file->total_atracks\n");
   return 0;
   }
 
@@ -728,8 +756,7 @@ void lqt_seek_video(quicktime_t * file, int track, int64_t time)
                              &(file->vtracks[track].stts_index),
                              &(file->vtracks[track].stts_count));
 
-  //  fprintf(stderr, "lqt_seek_video: %lld %lld\n", time, frame);
-  
+
   quicktime_set_video_position(file, frame, track);
   }
 
@@ -773,11 +800,8 @@ int lqt_read_video_frame(quicktime_t * file,
     *buffer = realloc(*buffer, *buffer_alloc);
     }
 
-  //  fprintf(stderr, "calling quicktime_read_data\n");
   result = quicktime_read_data(file, *buffer, len);
 
-  //  fprintf(stderr, "lqt_read_video_frame: %lld %d %d\n",
-  //          offset, len, result);
 
   if(result < len)
     {
@@ -898,7 +922,7 @@ void lqt_set_cmodel(quicktime_t *file, int track, int colormodel)
   if((track < file->total_vtracks) && (track >= 0))
     file->vtracks[track].io_cmodel = colormodel;
   else
-    fprintf(stderr, "lqt_set_cmodel: No track No. %d\n", track);
+    lqt_log(file, LQT_LOG_ERROR, LOG_DOMAIN, "lqt_set_cmodel: No track No. %d", track);
   }
 
 void quicktime_set_row_span(quicktime_t *file, int row_span)
@@ -1213,7 +1237,6 @@ void quicktime_insert_keyframe(quicktime_t *file, long frame, int track)
         // Offset 1
 	frame++;
         
-//printf("quicktime_insert_keyframe 1\n");
 // Get the keyframe greater or equal to new frame
 	for(i = 0; i < stss->total_entries; i++)
 	{
@@ -1247,7 +1270,6 @@ void quicktime_insert_keyframe(quicktime_t *file, long frame, int track)
 		stss->table[i].sample = frame;
 
 	stss->total_entries++;
-//printf("quicktime_insert_keyframe 2 %d\n", stss->total_entries);
 }
 
 
@@ -1316,6 +1338,8 @@ int quicktime_delete_audio_map(quicktime_audio_map_t *atrack)
         return 0;
 }
 
+// Initialize maps, for reading only
+
 void quicktime_init_maps(quicktime_t * file)
   {
   int i, dom, track;
@@ -1324,7 +1348,7 @@ void quicktime_init_maps(quicktime_t * file)
 
   if(file->total_atracks)
     {
-    file->atracks = (quicktime_audio_map_t*)calloc(1, sizeof(quicktime_audio_map_t) * file->total_atracks);
+    file->atracks = calloc(1, sizeof(*file->atracks) * file->total_atracks);
     for(i = 0, track = 0; i < file->total_atracks; i++, track++)
       {
       while(!file->moov.trak[track]->mdia.minf.is_audio)
@@ -1341,7 +1365,7 @@ void quicktime_init_maps(quicktime_t * file)
 
   if(file->total_vtracks)
     {
-    file->vtracks = (quicktime_video_map_t*)calloc(1, sizeof(quicktime_video_map_t) * file->total_vtracks);
+    file->vtracks = calloc(1, sizeof(*file->vtracks) * file->total_vtracks);
     
     for(track = 0, i = 0; i < file->total_vtracks; i++, track++)
       {
@@ -1375,6 +1399,26 @@ void quicktime_init_maps(quicktime_t * file)
         }
       }
     }
+
+  /* Text tracks */
+
+  file->total_ttracks = lqt_text_tracks(file);
+
+  if(file->total_ttracks)
+    {
+    file->ttracks = calloc(file->total_ttracks, sizeof(*file->ttracks));
+
+    for(track = 0, i = 0; i < file->total_ttracks; i++, track++)
+      {
+      while(!file->moov.trak[track]->mdia.minf.is_text)
+        track++;
+      lqt_init_text_map(file,
+                        &file->ttracks[i], file->moov.trak[track], 0);
+      }
+    }
+  
+  
+
   }
 
 int quicktime_read_info(quicktime_t *file)
@@ -1418,7 +1462,6 @@ int quicktime_read_info(quicktime_t *file)
 /* McRoweSoft AVI section */
         if(file->file_type == LQT_FILE_AVI)
         {
-//printf("quicktime_read_info 1\n");
 /* Import first RIFF */
                 do
                 {
@@ -1436,11 +1479,9 @@ int quicktime_read_info(quicktime_t *file)
                         !got_header &&
                         quicktime_position(file) < file->total_length);
                                                                                                                   
-//printf("quicktime_read_info 10\n");
 /* Construct indexes. */
                 if(quicktime_import_avi(file))
                   return 1;
-                //printf("quicktime_read_info 20\n");
         }
 /* Quicktime section */
         else
@@ -1460,6 +1501,7 @@ int quicktime_read_info(quicktime_t *file)
                                 if(quicktime_atom_is(&leaf_atom, "ftyp"))
                                 {
                                         quicktime_read_ftyp(file, &file->ftyp, &leaf_atom);
+                                        file->file_type = quicktime_ftyp_get_file_type(&file->ftyp);
                                         file->has_ftyp = 1;
                                 }
                                 else
@@ -1581,17 +1623,19 @@ int quicktime_read_info(quicktime_t *file)
 /* Shut down preload in case of an obsurdly high temp_size */
         quicktime_set_preload(file, 0);
                                                                                                                   
-//printf("quicktime_read_info 100\n");
         return !got_header;
 }
 
 
 int quicktime_dump(quicktime_t *file)
 {
-	printf("quicktime_dump\n");
-	printf("movie data\n");
-	printf(" size %lld\n", file->mdat.atom.size);
-	printf(" start %lld\n", file->mdat.atom.start);
+	lqt_dump("quicktime_dump\n");
+        if(file->has_ftyp)
+          quicktime_ftyp_dump(&(file->ftyp));
+	
+        lqt_dump("movie data (mdat)\n");
+	lqt_dump(" size %lld\n", file->mdat.atom.size);
+	lqt_dump(" start %lld\n", file->mdat.atom.start);
 	quicktime_moov_dump(&(file->moov));
 	if (lqt_qtvr_get_object_track(file) >= 0)
 	{
@@ -1655,7 +1699,6 @@ int quicktime_check_sig(char *path)
                 }
         }
                                                                                                                   
-//printf(__FUNCTION__ " 2 %d\n", result2);
         quicktime_file_close(&file);
         quicktime_delete(&file);
         return result2;
@@ -1672,7 +1715,8 @@ int quicktime_is_avi(quicktime_t *file)
 return !!(file->file_type & (LQT_FILE_AVI|LQT_FILE_AVI_ODML));
 }
 
-quicktime_t* do_open(const char *filename, int rd, int wr, lqt_file_type_t type)
+static quicktime_t* do_open(const char *filename, int rd, int wr, lqt_file_type_t type,
+                            lqt_log_callback_t log_cb, void * log_data)
 {
         int i;
 	quicktime_t *new_file;
@@ -1680,9 +1724,12 @@ quicktime_t* do_open(const char *filename, int rd, int wr, lqt_file_type_t type)
 
         new_file = calloc(1, sizeof(*new_file));
 
+        new_file->log_callback = log_cb;
+        new_file->log_data = log_data;
+        
         if(rd && wr)
           {
-	  fprintf(stderr, "read/write mode is not supported\n");
+	  lqt_log(new_file, LQT_LOG_ERROR, LOG_DOMAIN, "read/write mode is not supported");
           free(new_file);
           return (quicktime_t*)0;
           }
@@ -1710,17 +1757,12 @@ quicktime_t* do_open(const char *filename, int rd, int wr, lqt_file_type_t type)
             {
             if(quicktime_read_info(new_file))
               {
+              lqt_log(new_file, LQT_LOG_ERROR, LOG_DOMAIN, "Opening failed (unsupported filetype)");
               quicktime_close(new_file);
-//              fprintf(stderr, "quicktime_open: error in header\n");
               new_file = 0;
               }
-            //printf("quicktime_open 3\n");
-            /* Set file type */
-            else if(new_file->has_ftyp)
-              new_file->file_type = quicktime_ftyp_get_file_type(&(new_file->ftyp));
             }
           
-          //printf("quicktime_open 4 %d %d\n", wr, exists);
           /* start the data atom */
           /* also don't want to do this if making a streamable file */
           if(wr)
@@ -1745,7 +1787,6 @@ quicktime_t* do_open(const char *filename, int rd, int wr, lqt_file_type_t type)
           new_file = 0;
           }
         
-        //printf("quicktime_open 5 %llx %llx\n", new_file->ftell_position, new_file->file_position);
         
         
 	if(rd && new_file)
@@ -1763,19 +1804,31 @@ quicktime_t* do_open(const char *filename, int rd, int wr, lqt_file_type_t type)
 
 quicktime_t* quicktime_open(const char *filename, int rd, int wr)
   {
-  return do_open(filename, rd, wr, LQT_FILE_QT_OLD);
+  return do_open(filename, rd, wr, LQT_FILE_QT_OLD, NULL, NULL);
   }
 
 quicktime_t * lqt_open_read(const char * filename)
   {
-  return do_open(filename, 1, 0, LQT_FILE_NONE);
+  return do_open(filename, 1, 0, LQT_FILE_NONE, NULL, NULL);
   }
 
 quicktime_t * lqt_open_write(const char * filename, lqt_file_type_t type)
   {
-  return do_open(filename, 0, 1, type);
+  return do_open(filename, 0, 1, type, NULL, NULL);
   }
 
+quicktime_t * lqt_open_read_with_log(const char * filename, lqt_log_callback_t cb, void * log_data)
+  {
+  return do_open(filename, 1, 0, LQT_FILE_NONE, cb, log_data);
+  }
+
+quicktime_t * lqt_open_write_with_log(const char * filename, lqt_file_type_t type,
+                                      lqt_log_callback_t cb, void * log_data)
+  {
+  return do_open(filename, 0, 1, type, cb, log_data);
+  }
+
+
 int quicktime_close(quicktime_t *file)
   {
   int i;
@@ -1790,26 +1843,32 @@ int quicktime_close(quicktime_t *file)
       quicktime_atom_t junk_atom;
       int64_t position = quicktime_position(file);
 #endif
-      // Finalize last header
-      quicktime_finalize_riff(file, file->riff[file->total_riffs - 1]);
-      // Finalize the odml header
-      quicktime_finalize_odml(file, &file->riff[0]->hdrl);
-
-      if(file->file_type == LQT_FILE_AVI_ODML)
+      // total_riffs is 0 if no A/V frames have been written
+      if(file->total_riffs)
         {
-        for(i = 0; i < file->moov.total_tracks; i++)
+        // Finalize last header
+        quicktime_finalize_riff(file, file->riff[file->total_riffs - 1]);
+        // Finalize the odml header
+        quicktime_finalize_odml(file, &file->riff[0]->hdrl);
+        
+        if(file->file_type == LQT_FILE_AVI_ODML)
           {
-          quicktime_finalize_indx(file, &file->moov.trak[i]->strl->indx);
+          for(i = 0; i < file->moov.total_tracks; i++)
+            {
+            quicktime_finalize_indx(file, &file->moov.trak[i]->strl->indx);
+            }
           }
         }
-      
       }
     else
       {
       if (lqt_qtvr_get_object_track(file) >= 0)
         {
-        lqt_qtvr_add_node(file);
-        lqt_qtvr_add_node(file);
+        lqt_qtvr_add_object_node(file);
+        }
+      else if (lqt_qtvr_get_panorama_track(file) >= 0)
+        {
+        lqt_qtvr_add_panorama_node(file);
         }
       // Atoms are only written here
       quicktime_atom_write_footer(file, &file->mdat.atom);
@@ -1839,7 +1898,6 @@ static void apply_default_parameters(quicktime_t * file,
   lqt_parameter_info_t * parameter_info;
   int j;
 
-  //  fprintf(stderr, "APPLY CODEC INFO %s %d\n", codec_info->name, encode);
   
   if(encode)
     {
@@ -1857,30 +1915,24 @@ static void apply_default_parameters(quicktime_t * file,
     switch(parameter_info[j].type)
       {
       case LQT_PARAMETER_INT:
-#ifndef NDEBUG
-        fprintf(stderr, "Setting Parameter %s to %d\n",
+        lqt_log(file, LQT_LOG_DEBUG, LOG_DOMAIN, "Setting parameter %s to %d",
                 parameter_info[j].name,
                 parameter_info[j].val_default.val_int);
-#endif
         codec->set_parameter(file, track, parameter_info[j].name,
                              &(parameter_info[j].val_default.val_int));
         break;
       case LQT_PARAMETER_FLOAT:
-#ifndef NDEBUG
-        fprintf(stderr, "Setting Parameter %s to %f\n",
+        lqt_log(file, LQT_LOG_DEBUG, LOG_DOMAIN, "Setting parameter %s to %f",
                 parameter_info[j].name,
                 parameter_info[j].val_default.val_float);
-#endif
         codec->set_parameter(file, track, parameter_info[j].name,
                              &(parameter_info[j].val_default.val_float));
         break;
       case LQT_PARAMETER_STRING:
       case LQT_PARAMETER_STRINGLIST:
-#ifndef NDEBUG
-        fprintf(stderr, "Setting Parameter %s to %s\n",
+        lqt_log(file, LQT_LOG_DEBUG, LOG_DOMAIN, "Setting parameter %s to %s",
                 parameter_info[j].name,
                 parameter_info[j].val_default.val_string);
-#endif
         codec->set_parameter(file, track, parameter_info[j].name,
                              &(parameter_info[j].val_default.val_string));
         break;
@@ -2022,11 +2074,6 @@ int64_t * lqt_get_chunk_sizes(quicktime_t * file, quicktime_trak_t *trak)
       ret[i] = file->mdat.atom.start +  file->mdat.atom.size - trak->mdia.minf.stbl.stco.table[i].offset;
       if(ret[i] < 0)
         ret[i] = 0;
-#if 0
-      fprintf(stderr, "Chunk size %lld, file->mdat.atom.start: %lld file->mdat.atom.size: %lld, trak->mdia.minf.stbl.stco.table[i].offset: %lld\n",
-              ret[i], file->mdat.atom.start, file->mdat.atom.size,
-              trak->mdia.minf.stbl.stco.table[i].offset);
-#endif
       }
     }
   free(chunk_indices);
@@ -2049,11 +2096,6 @@ int lqt_read_audio_chunk(quicktime_t * file, int track,
     file->atracks[track].eof = 1;
     return 0;
     }
-#if 0
-  fprintf(stderr, "lqt_read_audio_chunk %d %d\n",
-          chunk,
-          file->atracks[track].track->mdia.minf.stbl.stco.total_entries);
-#endif
   if(!trak->chunk_sizes)
     {
     trak->chunk_sizes = lqt_get_chunk_sizes(file, trak);
@@ -2142,8 +2184,7 @@ interlace_modes[] =
   {
     { LQT_INTERLACE_NONE,         "None (Progressive)" },
     { LQT_INTERLACE_TOP_FIRST,    "Top field first"    },
-    { LQT_INTERLACE_BOTTOM_FIRST, "Bottom field first" },
-    {  /* End of array */ }
+    { LQT_INTERLACE_BOTTOM_FIRST, "Bottom field first" }
   };
   
 lqt_interlace_mode_t lqt_get_interlace_mode(quicktime_t * file, int track)
@@ -2153,16 +2194,24 @@ lqt_interlace_mode_t lqt_get_interlace_mode(quicktime_t * file, int track)
   return file->vtracks[track].interlace_mode;
   }
 
+int lqt_set_interlace_mode(quicktime_t * file, int track,
+                           lqt_interlace_mode_t mode)
+  {
+  if(track < 0 || track > file->total_vtracks)
+    return 0;
+  file->vtracks[track].interlace_mode = mode;
+  return 1;
+  }
+
 const char * lqt_interlace_mode_to_string(lqt_interlace_mode_t mode)
   {
-  int i = 0;
-  while(interlace_modes[i].name)
+  int i;
+  for(i = 0; i < sizeof(interlace_modes)/sizeof(interlace_modes[0]); i++)
     {
     if(interlace_modes[i].mode == mode)
       return interlace_modes[i].name;
-    i++;
     }
-  return (const char*)0;
+  return interlace_modes[0].name;
   }
 
 /* Chroma placement */
@@ -2176,20 +2225,18 @@ chroma_placements[] =
   {
     { LQT_CHROMA_PLACEMENT_DEFAULT,  "MPEG-1/JPEG" },
     { LQT_CHROMA_PLACEMENT_MPEG2,    "MPEG-2" },
-    { LQT_CHROMA_PLACEMENT_DVPAL,    "PAL DV" },
-    {  /* End of array */ }
+    { LQT_CHROMA_PLACEMENT_DVPAL,    "PAL DV" }
   };
 
-const char * lqt_chroma_placement_to_string(lqt_chroma_placement_t p)
+const char * lqt_chroma_placement_to_string(lqt_chroma_placement_t placement)
   {
-  int i = 0;
-  while(chroma_placements[i].name)
+  int i;
+  for(i = 0; i < sizeof(chroma_placements)/sizeof(chroma_placements[0]); i++)
     {
-    if(chroma_placements[i].placement == p)
+    if(chroma_placements[i].placement == placement)
       return chroma_placements[i].name;
-    i++;
     }
-  return (const char*)0;
+  return chroma_placements[0].name;
   }
 
 lqt_chroma_placement_t lqt_get_chroma_placement(quicktime_t * file, int track)
@@ -2213,20 +2260,18 @@ sample_formats[] =
     { LQT_SAMPLE_UINT8, "8 bit unsigned" },
     { LQT_SAMPLE_INT16, "16 bit signed" },
     { LQT_SAMPLE_INT32, "32 bit signed" },
-    { LQT_SAMPLE_FLOAT, "Floating point" }, /* Float is ALWAYS machine native */
-    {  /* End of array */ }
+    { LQT_SAMPLE_FLOAT, "Floating point" } /* Float is ALWAYS machine native */
   };
 
-const char * lqt_sample_format_to_string(lqt_sample_format_t s)
+const char * lqt_sample_format_to_string(lqt_sample_format_t format)
   {
-  int i = 0;
-  while(sample_formats[i].name)
+  int i;
+  for(i = 0; i < sizeof(sample_formats)/sizeof(sample_formats[0]); i++)
     {
-    if(sample_formats[i].format == s)
+    if(sample_formats[i].format == format)
       return sample_formats[i].name;
-    i++;
     }
-  return (const char*)0;
+  return sample_formats[0].name;
   }
 
 lqt_sample_format_t lqt_get_sample_format(quicktime_t * file, int track)
@@ -2252,8 +2297,6 @@ lqt_sample_format_t lqt_get_sample_format(quicktime_t * file, int track)
                                                           0, track);
 
       }
-    //    fprintf(stderr, "Obtained sampleformat: %s\n",
-    //            lqt_sample_format_to_string(atrack->sample_format));
     }
   
   return atrack->sample_format;
@@ -2276,7 +2319,6 @@ void lqt_start_audio_vbr_frame(quicktime_t * file, int track)
   {
   quicktime_audio_map_t * atrack = &file->atracks[track];
   atrack->vbr_frame_start = quicktime_position(file);
-  //  fprintf(stderr, "lqt_start_audio_vbr_frame\n");
   }
 
 void lqt_finish_audio_vbr_frame(quicktime_t * file, int track, int num_samples)
@@ -2299,8 +2341,6 @@ void lqt_finish_audio_vbr_frame(quicktime_t * file, int track, int num_samples)
   atrack->vbr_num_frames++;
   atrack->vbr_frames_written++;
 
-  //  fprintf(stderr, "lqt_finish_audio_vbr_frame (total_frames: %lld, samples: %d)\n",
-  //          atrack->vbr_frames_written, num_samples);
   
   }
 
@@ -2400,11 +2440,6 @@ int lqt_chunk_of_sample_vbr(int64_t *chunk_sample,
   *chunk_sample =
     get_uncompressed_samples(&trak->mdia.minf.stbl.stts, 0,
                              chunk_packet);
-#if 0
-  fprintf(stderr,
-          "lqt_chunk_of_sample_vbr, chunk_sample: %lld, chunk: %lld, sample: %lld\n",
-          *chunk_sample, *chunk, sample);
-#endif     
   return 0;
   }
 
@@ -2500,9 +2535,6 @@ int lqt_audio_read_vbr_packet(quicktime_t * file, int track, long chunk, int pac
     *buffer_alloc = packet_size + 128;
     *buffer = realloc(*buffer, *buffer_alloc);
     }
-#if 0
-  fprintf(stderr, "Read VBR packet, offset: %llx, size: %x, samples: %d\n", offset, packet_size, *samples);
-#endif
   quicktime_set_position(file, offset);
   quicktime_read_data(file, *buffer, packet_size);
   return packet_size;
@@ -2522,6 +2554,7 @@ filetypes[] =
       { LQT_FILE_AVI_ODML, "AVI ODML"          },
       { LQT_FILE_MP4,      "MP4"               },
       { LQT_FILE_M4A,      "M4A"               },
+      { LQT_FILE_3GP,      "3GP"               }
   };
   
 const char * lqt_file_type_to_string(lqt_file_type_t type)
