@@ -1,7 +1,29 @@
-#include <funcprotos.h>
-#include <quicktime/quicktime.h>
+/*******************************************************************************
+ stsc.c
 
+ libquicktime - A library for reading and writing quicktime/avi/mp4 files.
+ http://libquicktime.sourceforge.net
 
+ Copyright (C) 2002 Heroine Virtual Ltd.
+ Copyright (C) 2002-2007 Members of the libquicktime project.
+
+ This library is free software; you can redistribute it and/or modify it under
+ the terms of the GNU Lesser General Public License as published by the Free
+ Software Foundation; either version 2.1 of the License, or (at your option)
+ any later version.
+
+ This library is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+ details.
+
+ You should have received a copy of the GNU Lesser General Public License along
+ with this library; if not, write to the Free Software Foundation, Inc., 51
+ Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+*******************************************************************************/ 
+
+#include "lqt_private.h"
+#include <stdlib.h>
 
 void quicktime_stsc_init(quicktime_stsc_t *stsc)
 {
@@ -50,13 +72,13 @@ void quicktime_stsc_delete(quicktime_stsc_t *stsc)
 void quicktime_stsc_dump(quicktime_stsc_t *stsc)
 {
 	int i;
-	printf("     sample to chunk (stsc)\n");
-	printf("      version %d\n", stsc->version);
-	printf("      flags %ld\n", stsc->flags);
-	printf("      total_entries %ld\n", stsc->total_entries);
+	lqt_dump("     sample to chunk (stsc)\n");
+	lqt_dump("      version %d\n", stsc->version);
+	lqt_dump("      flags %ld\n", stsc->flags);
+	lqt_dump("      total_entries %ld\n", stsc->total_entries);
 	for(i = 0; i < stsc->total_entries; i++)
 	{
-		printf("       chunk %ld samples %lx id %ld\n", 
+		lqt_dump("       chunk %ld samples %lx id %ld\n", 
 			stsc->table[i].chunk, stsc->table[i].samples, stsc->table[i].id);
 	}
 }
@@ -83,7 +105,15 @@ void quicktime_write_stsc(quicktime_t *file, quicktime_stsc_t *stsc)
 {
 	int i, last_same;
 	quicktime_atom_t atom;
-	quicktime_atom_write_header(file, &atom, "stsc");
+
+        /* This can happen, if a stream was created, but no
+           samples have been written. The resulting file will be
+           invalid anyway, just don't let us crash */
+
+        if(!stsc->table) 
+          return;
+        
+        quicktime_atom_write_header(file, &atom, "stsc");
 
 	for(i = 1, last_same = 0; i < stsc->total_entries; i++)
 	{
