@@ -1,19 +1,37 @@
-#include "config.h"
+/*******************************************************************************
+ util.c
 
-#include <fcntl.h>
-#include <math.h>
-#include <stdio.h>
-#include <sys/ioctl.h>
+ libquicktime - A library for reading and writing quicktime/avi/mp4 files.
+ http://libquicktime.sourceforge.net
+
+ Copyright (C) 2002 Heroine Virtual Ltd.
+ Copyright (C) 2002-2007 Members of the libquicktime project.
+
+ This library is free software; you can redistribute it and/or modify it under
+ the terms of the GNU Lesser General Public License as published by the Free
+ Software Foundation; either version 2.1 of the License, or (at your option)
+ any later version.
+
+ This library is distributed in the hope that it will be useful, but WITHOUT
+ ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+ FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
+ details.
+
+ You should have received a copy of the GNU Lesser General Public License along
+ with this library; if not, write to the Free Software Foundation, Inc., 51
+ Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
+*******************************************************************************/ 
+
+#include "lqt_private.h"
+#include "lqt_fseek.h"
+#include "workarounds.h"
 #include <sys/stat.h>
-#include <time.h>
 #include <unistd.h>
-
-#include <funcprotos.h>
-#include <quicktime/quicktime.h>
-#include <lqt_fseek.h>
-#include <workarounds.h>
+#include <stdlib.h>
+#include <stdio.h>
 #include <string.h>
-
+#include <time.h>
+#include <math.h>
 
 #ifndef HAVE_LRINT
 #define lrint(x) ((long int)(x))
@@ -53,7 +71,6 @@ int quicktime_file_open(quicktime_t *file, const char *path, int rd, int wr)
 
 	if(!(file->stream = fopen(path, flags)))
 	{
-		perror(__FUNCTION__);
 		return 1;
 	}
 
@@ -61,7 +78,8 @@ int quicktime_file_open(quicktime_t *file, const char *path, int rd, int wr)
 	{
 		file->total_length = quicktime_get_file_length(path);		
 	}
-      file->presave_buffer = calloc(1, QUICKTIME_PRESAVE);	
+        if(wr)
+          file->presave_buffer = calloc(1, QUICKTIME_PRESAVE);	
 	return 0;
 }
 
@@ -134,10 +152,20 @@ static int read_preload(quicktime_t *file, uint8_t *data, int64_t size)
 int quicktime_read_data(quicktime_t *file, uint8_t *data, int64_t size)
   {
   int result = 1;
+
+  /* Return if we had an error before */
+  if(file->io_error || file->io_eof)
+    return 0;
+  
   if(!file->preload_size)
     {
     quicktime_fseek(file, file->file_position);
     result = fread(data, 1, size, file->stream);
+    if(result < size)
+      {
+      file->io_error = ferror(file->stream);
+      file->io_eof   = feof(file->stream);
+      }
     file->ftell_position += size;
     }
   else
@@ -150,11 +178,13 @@ int quicktime_read_data(quicktime_t *file, uint8_t *data, int64_t size)
     if(selection_end - selection_start > file->preload_size)
       {
       /* Size is larger than preload size.  Should never happen. */
-      // printf("read data Size is larger than preload size. size=%llx preload_size=%llx\n",
-      //       (long long)(selection_end - selection_start),
-      //       (long long)(file->preload_size));
       quicktime_fseek(file, file->file_position);
       result = fread(data, 1, size, file->stream);
+      if(result < size)
+        {
+        file->io_error = ferror(file->stream);
+        file->io_eof   = feof(file->stream);
+        }
       file->ftell_position += size;
       }
     else if(selection_start >= file->preload_start && 
@@ -194,6 +224,12 @@ int quicktime_read_data(quicktime_t *file, uint8_t *data, int64_t size)
         quicktime_fseek(file, file->preload_end);
         result = fread(&(file->preload_buffer[fragment_start]),
                        fragment_len, 1, file->stream);
+
+        if(result < fragment_len)
+          {
+          file->io_error = ferror(file->stream);
+          file->io_eof   = feof(file->stream);
+          }
         file->ftell_position += fragment_len;
         file->preload_end += fragment_len;
         fragment_start += fragment_len;
@@ -210,6 +246,11 @@ int quicktime_read_data(quicktime_t *file, uint8_t *data, int64_t size)
       /* Replace entire preload buffer with range. */
       quicktime_fseek(file, file->file_position);
       result = fread(file->preload_buffer, 1, size, file->stream);
+      if(result < size)
+        {
+        file->io_error = ferror(file->stream);
+        file->io_eof   = feof(file->stream);
+        }
       file->ftell_position += size;
       file->preload_start = file->file_position;
       file->preload_end = file->file_position + size;
@@ -224,70 +265,72 @@ int quicktime_read_data(quicktime_t *file, uint8_t *data, int64_t size)
   }
 
 int quicktime_write_data(quicktime_t *file, uint8_t *data, int size)
-{
-        int data_offset = 0;
-        int writes_attempted = 0;
-        int writes_succeeded = 0;
-//printf("quicktime_write_data 1 %d\n", size);
-                                                                                                                  
-// Flush existing buffer and seek to new position
-        if(file->file_position != file->presave_position)
-        {
-                if(file->presave_size)
-                {
-                        quicktime_fseek(file, file->presave_position - file->presave_size);
-                        writes_succeeded += fwrite(file->presave_buffer, 1, file->presave_size, file->stream);
-                        writes_attempted += file->presave_size;
-                        file->presave_size = 0;
-                }
-                file->presave_position = file->file_position;
-        }
-                                                                                                                  
-// Write presave buffers until done
-        while(size > 0)
-        {
-                int fragment_size = QUICKTIME_PRESAVE;
-                if(fragment_size > size) fragment_size = size;
-                if(fragment_size + file->presave_size > QUICKTIME_PRESAVE)
-                        fragment_size = QUICKTIME_PRESAVE- file->presave_size;
-                                                                                                                  
-                memcpy(file->presave_buffer + file->presave_size,
-                        data + data_offset,
-                        fragment_size);
-                                                                                                                  
-                file->presave_position += fragment_size;
-                file->presave_size += fragment_size;
-                data_offset += fragment_size;
-                size -= fragment_size;
-                                                                                                                  
-                if(file->presave_size >= QUICKTIME_PRESAVE)
-                {
-//if(++iterations > 1) printf("quicktime_write_data 2 iterations=%d\n", iterations);
-                        quicktime_fseek(file, file->presave_position - file->presave_size);
-                        writes_succeeded += fwrite(file->presave_buffer, 1, file->presave_size, file->stream);
-                        writes_attempted += file->presave_size;
-                        file->presave_size = 0;
-                }
-        }
-                                                                                                                  
-/* Adjust file position */
-        file->file_position = file->presave_position;
-/* Adjust ftell position */
-        file->ftell_position = file->presave_position;
-/* Adjust total length */
-        if(file->total_length < file->ftell_position) file->total_length = file->ftell_position;
-                                                                                                                  
-/* fwrite failed */
-        if(!writes_succeeded && writes_attempted)
-        {
-                return 0;
-        }
-        else
-        if(!size)
-                return 1;
-        else
-                return size;
-}
+  {
+  int data_offset = 0;
+  int writes_attempted = 0;
+  int writes_succeeded = 0;
+
+  if(file->io_error)
+    return 0;
+  
+  // Flush existing buffer and seek to new position
+  if(file->file_position != file->presave_position)
+    {
+    if(file->presave_size)
+      {
+      quicktime_fseek(file, file->presave_position - file->presave_size);
+      writes_succeeded += fwrite(file->presave_buffer, 1, file->presave_size, file->stream);
+      writes_attempted += file->presave_size;
+      file->presave_size = 0;
+      }
+    file->presave_position = file->file_position;
+    }
+
+  // Write presave buffers until done
+  while(size > 0)
+    {
+    int fragment_size = QUICKTIME_PRESAVE;
+    if(fragment_size > size) fragment_size = size;
+    if(fragment_size + file->presave_size > QUICKTIME_PRESAVE)
+      fragment_size = QUICKTIME_PRESAVE- file->presave_size;
+
+    memcpy(file->presave_buffer + file->presave_size,
+           data + data_offset,
+           fragment_size);
+
+    file->presave_position += fragment_size;
+    file->presave_size += fragment_size;
+    data_offset += fragment_size;
+    size -= fragment_size;
+
+    if(file->presave_size >= QUICKTIME_PRESAVE)
+      {
+      quicktime_fseek(file, file->presave_position - file->presave_size);
+      writes_succeeded += fwrite(file->presave_buffer, 1, file->presave_size, file->stream);
+      writes_attempted += file->presave_size;
+      file->presave_size = 0;
+      }
+    }
+
+  /* Adjust file position */
+  file->file_position = file->presave_position;
+  /* Adjust ftell position */
+  file->ftell_position = file->presave_position;
+  /* Adjust total length */
+  if(file->total_length < file->ftell_position) file->total_length = file->ftell_position;
+
+  /* fwrite failed */
+  if(!writes_succeeded && writes_attempted)
+    {
+    file->io_error = ferror(file->stream);
+    return 0;
+    }
+  else
+    if(!size)
+      return 1;
+    else
+      return size;
+  }
 
 int64_t quicktime_byte_position(quicktime_t *file)
 {
@@ -580,7 +623,6 @@ float quicktime_read_fixed16(quicktime_t *file)
 	unsigned char data[2];
 	
 	quicktime_read_data(file, data, 2);
-//printf("quicktime_read_fixed16 %02x%02x\n", data[0], data[1]);
 	if(data[1])
 		return (float)data[0] + (float)data[1] / 256;
 	else
@@ -813,9 +855,9 @@ void quicktime_copy_char32(char *output, char *input)
 void quicktime_print_chars(char *desc, uint8_t *input, int len)
 {
 	int i;
-	printf("%s", desc);
-	for(i = 0; i < len; i++) printf("%02x ", input[i]);
-	printf("\n");
+	lqt_dump("%s", desc);
+	for(i = 0; i < len; i++) lqt_dump("%02x ", input[i]);
+	lqt_dump("\n");
 }
 
 unsigned long quicktime_current_time(void)
